@@ -1,19 +1,12 @@
 import smtplib
 from .logger.auto_logger import autolog
-import configparser
-
+from .configuration import *
 def send_email(receiver,msg):
 
     '''
     SEND MAIL TO THE USER WITH ANONFILES LINK
-    '''
-
-    settings = configparser.ConfigParser()
-    settings.read("config.ini")
-    sender = settings["MAIL"]["EMAIL"]       
-    password = settings["MAIL"]["PASSWORD"]  
- 
-    server = smtplib.SMTP(settings.get("MAIL","SMTP", fallback='smtp.gmail.com'), settings.get("MAIL","SMTP_PORT", fallback=587))
+    '''  
+    server = smtplib.SMTP(smtp, smtp_port)
     server.starttls()
     autolog("Sending Mail...")
     message = f"""
@@ -21,6 +14,10 @@ def send_email(receiver,msg):
     """
 
     try:
+        if sender is None or password is None:
+            autolog("mail.sender or mail.password is missing", 3)
+            exit(2)
+
         server.login(sender,password)
         server.sendmail(sender,receiver,message)
         autolog("Mail Sent Successfully")       
